#######
Modules
#######

ROMSearch contains a number of modules that can be switched on or off, or configured to the user's wishes. Here are
the available modules.

.. toctree::
  :glob:
  :titlesonly:
  :maxdepth: 2

  modules/romsearch
  modules/romdownloader
  modules/datparser
  modules/dupeparser
  modules/gamefinder
  modules/romparser
  modules/romchooser
  modules/rommover
